SystemOrganization addCategory: #MOOCContactBook!
SystemOrganization addCategory: 'MOOCContactBook-Tests'!

TestCase subclass: #MOOCContactTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MOOCContactBook-Tests'!

!MOOCContactTest commentStamp: 'RichardMyatt 7/25/2017 15:34' prior: 0!
A class to hold the tests for our contact application.  Taken from the Pharo MOOC.!

!MOOCContactTest methodsFor: 'tests' stamp: 'RichardMyatt 7/25/2017 19:17'!
testAddingOfContact
	"test that the method for adding a contact to the Contact Book
	 works in the expected way"

	| contact1 contact2 addressBook |
	contact1 := MOOCContact newNamed: 'Harry Potter' email: 'h.potter@horrorhall.com'.
	contact2 := MOOCContact newNamed: 'Marcus Denkeer' email: 'marcus.denker@inria.fr'.
	addressBook := MOOCContactBook new addContact: contact1; addContact: contact2.
	self assert: (addressBook contacts includes: contact1).
	self assert: (addressBook contacts includes: contact2)
	! !

!MOOCContactTest methodsFor: 'tests' stamp: 'RichardMyatt 7/25/2017 17:05'!
testCreation
	"test the creation of a contact"

	| contact |
	contact := MOOCContact newNamed: 'Marcus Denker' email: 'marcus.denker@intia.fr'.
	self assert: contact fullname = 'Marcus Denker'.
	self assert: contact email = 'marcus.denker@intia.fr'.! !

!MOOCContactTest methodsFor: 'tests' stamp: 'RichardMyatt 7/25/2017 19:39'!
testRemovingAContact
	"test that the method for adding a contact to the Contact Book
	 works in the expected way"

	| contact1 contact2 contact3 contact4 contact5 addressBook |
	contact1 := MOOCContact newNamed: 'Harry Potter' email: 'h.potter@horrorhall.com'.
	contact2 := MOOCContact newNamed: 'Marcus Denkeer' email: 'marcus.denker@inria.fr'.
	contact3 := MOOCContact newNamed: 'Hope Zimmerman' email: 'happyland@hopezee.com'.
	contact4 := MOOCContact newNamed: 'Spiderman' email: 'aracnoman@spidercentral.co.uk'.
	contact5 := MOOCContact newNamed: 'Lone Ranger' email: 'cowboy@theranch.ie'.
	addressBook := MOOCContactBook new
										addContact: contact1;
										addContact: contact2;
										addContact: contact3;
										addContact: contact4;
										addContact: contact5.
	self assert: (addressBook contacts includes: contact1).
	self assert: (addressBook contacts includes: contact2).
	addressBook removeContact: contact1.
	self assert: (addressBook contacts includes: contact1) not.
	! !

Object subclass: #MOOCContact
	instanceVariableNames: 'fullname email'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MOOCContactBook'!

!MOOCContact commentStamp: 'RichardMyatt 7/25/2017 18:53' prior: 0!
An example taken from the Pharo MOOC.

I represent a person with a name and an email address. I'm usually
part of a contact book.!

!MOOCContact class methodsFor: 'instance creation' stamp: 'RichardMyatt 7/25/2017 18:41'!
newNamed: aNameString email: anEmailString
	"Create a new contact instance with a name and email"

	^ self new 
			fullname: aNameString;
			email: anEmailString;
			yourself! !

!MOOCContact methodsFor: 'accessing' stamp: 'RichardMyatt 7/25/2017 16:55'!
email
	"answer the email address of the contact"
	
	^ email! !

!MOOCContact methodsFor: 'accessing' stamp: 'RichardMyatt 7/25/2017 16:56'!
email: aString
	"set the email address of the contact"
	
	email := aString! !

!MOOCContact methodsFor: 'accessing' stamp: 'RichardMyatt 7/25/2017 16:53'!
fullname
	"answer the full name of the contact"
	
	^ fullname! !

!MOOCContact methodsFor: 'accessing' stamp: 'RichardMyatt 7/25/2017 16:55'!
fullname: aString
	"set the full name of the contact"
	
	fullname := aString ! !

!MOOCContact methodsFor: 'printing' stamp: 'RichardMyatt 7/25/2017 18:52'!
printOn: aStream
	"customise the printing of the MOOCContact object"
	
	super printOn: aStream.
	aStream
			nextPutAll: ' -- '; 
			nextPutAll: self fullname;
			nextPutAll: ' <';
			nextPutAll: self email;
			nextPutAll: '>'! !

Object subclass: #MOOCContactBook
	instanceVariableNames: 'contacts'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MOOCContactBook'!

!MOOCContactBook commentStamp: 'RichardMyatt 7/25/2017 18:56' prior: 0!
I am a Contact Book which holds contacts.

This is an example taken from the Pharo MOOC.!

!MOOCContactBook class methodsFor: 'demos' stamp: 'RichardMyatt 7/25/2017 19:32'!
createDemoContactBook
	"create a set of demo contacts and populate a Contact Book
	 for testing purposes"

	| contact1 contact2 contact3 contact4 contact5 addressBook |
	contact1 := MOOCContact newNamed: 'Harry Potter' email: 'h.potter@horrorhall.com'.
	contact2 := MOOCContact newNamed: 'Marcus Denkeer' email: 'marcus.denker@inria.fr'.
	contact3 := MOOCContact newNamed: 'Hope Zimmerman' email: 'happyland@hopezee.com'.
	contact4 := MOOCContact newNamed: 'Spiderman' email: 'aracnoman@spidercentral.co.uk'.
	contact5 := MOOCContact newNamed: 'Lone Ranger' email: 'cowboy@theranch.ie'.
	addressBook := MOOCContactBook new
										addContact: contact1;
										addContact: contact2;
										addContact: contact3;
										addContact: contact4;
										addContact: contact5.
	^ addressBook! !

!MOOCContactBook methodsFor: 'action' stamp: 'RichardMyatt 7/25/2017 19:00'!
addContact: aContact
	"add a contact to the address book"

	self contacts add: aContact! !

!MOOCContactBook methodsFor: 'accessing' stamp: 'RichardMyatt 7/25/2017 18:59'!
contacts
	"a form of lazy initialization"

	^ contacts ifNil: [ contacts := OrderedCollection new ]! !

!MOOCContactBook methodsFor: 'action' stamp: 'RichardMyatt 7/25/2017 19:01'!
removeContact: aContact
	"remove a contact from the address book"

	self contacts remove: aContact! !
